
Version 0.0.1 release                                                 2026-03-11
--------------------------------------------------------------------------------

* For a list of bug fixes, see
  https://github.com/radical-cybertools/radical.radical.edge/issues?q=is%3Aissue+is%3Aclosed+sort%3Aupdated-desc
* For a list of open issues and known problems, see
  https://github.com/radical-cybertools/radical.radical.edge/issues?q=is%3Aissue+is%3Aopen+

* initial release for radical project 'radical.edge'

  ------------------------------------------------------------------------------
